==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Navegadores");
define("_OPERATINGSYS","Sistema Operacional");
define("_UNKNOWN","Desconhecido");
define("_OTHER","Outro / Desconhecido");
define("_MISCSTATS","Estatsticas Diversas");
define("_REGUSERS","Usurios Registrados:");
define("_ACTIVEAUTHORS","Autores Ativos:");
define("_STORIESPUBLISHED","Histrias Publicadas:");
define("_SACTIVETOPICS","Tpicos Ativos:");
define("_COMMENTSPOSTED","Comentrios Enviados:");
define("_SSPECIALSECT","Sees Especiais:");
define("_ARTICLESSEC","Artigos em Sees:");
define("_LINKSINLINKS","Links em Web Links:");
define("_LINKSCAT","Categorias em Links:");
define("_NEWSWAITING","Noticas Esperando Publicao:");
define("_NUKEVERSION","Verso do PHP-Nuke:");
define("_SEARCHENGINES","Sistemas de Busca");
define("_BOTS","Rbos/Aranhas");
define("_STATS","Estatsticas de Acesso");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Navegadores");
define("_OPERATINGSYS","Sistema Operacional");
define("_UNKNOWN","Desconhecido");
define("_OTHER","Outro / Desconhecido");
define("_MISCSTATS","Estatsticas Diversas");
define("_REGUSERS","Usurios Registrados:");
define("_ACTIVEAUTHORS","Autores Ativos:");
define("_STORIESPUBLISHED","Histrias Publicadas:");
define("_SACTIVETOPICS","Tpicos Ativos:");
define("_COMMENTSPOSTED","Comentrios Enviados:");
define("_SSPECIALSECT","Sees Especiais:");
define("_ARTICLESSEC","Artigos em Sees:");
define("_LINKSINLINKS","Links em Web Links:");
define("_LINKSCAT","Categorias em Links:");
define("_NEWSWAITING","Noticas Esperando Publicao:");
define("_NUKEVERSION","Verso do PHP-Nuke:");
define("_SEARCHENGINES","Sistemas de Busca");
define("_BOTS","Rbos/Aranhas");
define("_STATS","Estatsticas de Acesso");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
